@@ -15,7 +15,7 @@ class Sphere:
     ----------
     radius : float
         Radius of sphere
-    center : np.ndarray
+    center : np.ndarray[float]
         x,y,z coordinates of sphere center
 
     Attributes
@@ -24,9 +24,9 @@ class Sphere:
         Radius of sphere
     radius2 : float
         Squared radius of sphere
-    center : np.ndarray
+    center : np.ndarray[float]
         x,y,z coordinates of sphere center
-    center_dist : np.ndarray
+    center_dist : np.ndarray[float]
         Distance to center from origin
     """
     __slots__ = 'radius', 'radius2', 'center', 'center_dist'
@@ -61,27 +61,27 @@ class Sphere:
         """
 
         # Find projection of ray onto sphere centre-origin vector
-        tc = np.dot(self.center, ray.cart)
+        p = np.dot(self.center, ray.cart)
 
-        if tc < 0.:
+        if p < 0.:
             return False, 0., 0.
         # Find minimum sphere centre to ray distance (squared)
-        d2 = self.center_dist**2 - tc**2
+        d2 = self.center_dist**2 - p**2
         if d2 > self.radius2:
             return False, 0., 0.
-        t1c = np.sqrt(self.radius2-d2)
+        t = np.sqrt(self.radius2-d2)
 
         # Find ray-sphere intersection points
-        # These are scalars in vector equation of line
-        # P1 = O + t1*rhat
-        # P2 = O + t2*rhat
-        # where P1 is some point on the ray, rhat is the
+        # These are scalars used in the vector equation of line
+        # P1 = O + (p-t)*uhat
+        # P2 = O + (p+t)*uhat
+        # where P1 is intersection point on the ray, uhat is the
         # normalised ray vector, and O is a point in space,
         # in this case the origin
-        t1 = tc - t1c
-        t2 = tc + t1c
+        p1 = p - t
+        p2 = p + t
 
-        return True, t1, t2
+        return True, p1, p2
 
 
 class Ray:
@@ -112,13 +112,13 @@ class Ray:
         y component of ray vector in cartesian coordinates
     z : float
         z component of ray vector in cartesian coordinates
-    cart : np.ndarray
+    cart : np.ndarray[float]
         Direction vector of ray as (3,) np.array
     intersection : bool
         True if ray intersects with object
     r_i : float
         Distance to intersection point from origin
-    cart_i : np.ndarray
+    cart_i : np.ndarray[float]
         Position vector of intersection point as (3,) np.array
 
     """
