@@ -14,7 +14,7 @@ def create_zcw_rays(density):
     algorithm
 
     See Appendix I in
-        M. Eden and M. H. Levitt, J. Magn. Res., 1998, 132, 220-239.
+        Eden, M.; Levitt, M. H. J. Magn. Res., 1998, 132, 220-239.
 
     Parameters
     ----------
@@ -23,7 +23,7 @@ def create_zcw_rays(density):
 
     Returns
     -------
-    list
+    list[Ray]
         List of ray objects
     """
 
@@ -53,7 +53,7 @@ def recursive_g(m):
 
     Returns
     -------
-    int:
+    int
         g_m value for given m
 
     """
@@ -69,6 +69,35 @@ def recursive_g(m):
 
 
 def plot_rays(vecs, clusters, n_clust, show=True, fig=None, colours=None):
+    """
+    Create a plot of unblocked rays for web browser using plotly
+
+    Parameters
+    ----------
+    vecs : np.ndarray[float]
+        (3,n_unblocked_rays) array containing xyz vectors of unblocked rays
+    clusters : np.ndarray[int]
+        Integers specifying which cluster each ray belongs to
+    n_clust : int
+        Number of clusters
+    show : bool
+        If true, displays figure in browser
+    fig : plotly graph objects figure object
+        If provided, rays are added to this figure
+    colours : list[str]
+        List of colours, one per cluster formatted as
+        [
+            "rgb(VAL, VAL, VAL)",
+            "rgb(VAL, VAL, VAL)",
+            ...
+        ]
+        where VAL is Red, Green, Blue in range(0, 255)
+
+    Returns
+    -------
+    plotly graph objects figure object
+        Figure of unblocked rays as points
+    """
 
     if not colours:
         colours = [
